intelmq.bots.experts.field_reducer package — intelmq 3.1.0.alpha1 documentation

# intelmq.bots.experts.field_reducer package

## Submodules

## intelmq.bots.experts.field_reducer.expert module

Reducer bot

intelmq.bots.experts.field_reducer.expert.BOT

  alias of `intelmq.bots.experts.field_reducer.expert.FieldReducerExpertBot`

class intelmq.bots.experts.field_reducer.expert.FieldReducerExpertBot(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.lib.bot.ExpertBot`

  Remove fields from events

  init()
  keys = None
  process()
  type = None

## Module contents